summaryrefslogtreecommitdiff
path: root/summer-ospp-replace-isomd5sum-with-isosm3sum.patch
blob: ccdbd8ddb5b808958ef805e647a495a756c2b3c2 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
diff --git a/dracut/anaconda-diskroot b/dracut/anaconda-diskroot
index 295b0b5..3eee5a9 100755
--- a/dracut/anaconda-diskroot
+++ b/dracut/anaconda-diskroot
@@ -5,8 +5,8 @@
 . /lib/anaconda-lib.sh
 command -v getargbool >/dev/null || . /lib/dracut-lib.sh
 
-# Run checkisomd5 on a device
-run_checkisomd5() {
+# Run checkisosm3 on a device
+run_checkisosm3() {
     livedev=$1
     if getargbool 0 rd.live.check -d check; then
         [ -b "$livedev" ] && fs=$(blkid -s TYPE -o value "$livedev")
@@ -14,13 +14,13 @@ run_checkisomd5() {
             [ -x /bin/plymouth ] && /bin/plymouth --hide-splash
             if [ -n "$DRACUT_SYSTEMD" ]; then
                 p=$(dev_unit_name "$livedev")
-                systemctl start "checkisomd5@${p}.service"
-                retcode=$(systemctl -p ExecMainStatus show "checkisomd5@${p}.service")
-                status=$(systemctl -p ActiveState show "checkisomd5@${p}.service")
+                systemctl start "checkisosm3@${p}.service"
+                retcode=$(systemctl -p ExecMainStatus show "checkisosm3@${p}.service")
+                status=$(systemctl -p ActiveState show "checkisosm3@${p}.service")
                 splitsep "=" "$retcode" ignore rc
                 splitsep "=" "$status" ignore state
             else
-                checkisomd5 --verbose "$livedev"
+                checkisosm3 --verbose "$livedev"
                 rc=$?
                 state="inactive"
             fi
@@ -81,4 +81,4 @@ fi
 info "anaconda using disk root at $dev"
 mount -o ro "$dev" "$repodir" || warn "Couldn't mount $dev"
 anaconda_live_root_dir "$repodir" "$path"
-run_checkisomd5 "$dev"
+run_checkisosm3 "$dev"
diff --git a/pyanaconda/ui/gui/spokes/installation_source.py b/pyanaconda/ui/gui/spokes/installation_source.py
index 5b55792..935c24b 100644
--- a/pyanaconda/ui/gui/spokes/installation_source.py
+++ b/pyanaconda/ui/gui/spokes/installation_source.py
@@ -292,14 +292,14 @@ class MediaCheckDialog(GUIObject):
 
     def run(self, device_path):
         (retval, self._pid, _stdin, stdout, _stderr) = \
-            glib.spawn_async_with_pipes(None, ["checkisomd5", "--gauge", device_path], [],
+            glib.spawn_async_with_pipes(None, ["checkisosm3", "--gauge", device_path], [],
                                         glib.SpawnFlags.DO_NOT_REAP_CHILD |
                                         glib.SpawnFlags.SEARCH_PATH,
                                         None, None)
         if not retval:
             return
 
         # This function waits for checkisomd5 to end and then cleans up after it.
         PidWatcher().watch_process(self._pid, self._check_iso_ends_cb)
 
         # This function watches the process's stdout.
@@ -292,14 +292,14 @@ class MediaCheckDialog(GUIObject):
             return
 
-        # This function waits for checkisomd5 to end and then cleans up after it.
+        # This function waits for checkisosm3 to end and then cleans up after it.
         PidWatcher().watch_process(self._pid, self._check_iso_ends_cb)
 